SQ_Detail Zbox

His Dad [05-10-15 - 06:53]
SQ_Detail Zbox
Filename
HistOffline.lua
diff --git a/HistOffline.lua b/HistOffline.lua
index 8f3cffe..bf904a3 100644
--- a/HistOffline.lua
+++ b/HistOffline.lua
@@ -118,45 +118,50 @@ end

 -- Create SkillQuest Achievements Detail Boxes=======================
 -- These are the same for all chars, we just just hightlight the contents appropriately
-
-SQ_Detail_box= {}
+SQ_Detail_box = {}
+function load_SQ_Detail(lang)	-- called per account when we know the lingua
+	if SQ_Detail_box[lang] ~=nil then	--already done
+		return
+	end
+	SQ_Detail_box[lang]= {}
 --		accounts[acc].name[char].SQ_Frame = iup.frame{title = "Quest Details"} -- Panel for details

-local info, name, link
-for key, info in pairs(SQ_Info) do	-- for each zone
-	--print (key, dump(info))
-	SQ_Detail_box[key]= iup.matrix {numcol=2, numcol_visible=2,  numlin=0}
-
-	local Line = 1
-	SQ_Detail_box[key]:setcell(0,0, L.Ach_ID)
-	SQ_Detail_box[key]:setcell(0,1, L.Name)
-	SQ_Detail_box[key]:setcell(0,2, L.Link)
-	iup.SetAttribute(SQ_Detail_box[key], "READONLY", "YES")
-	iup.SetAttribute(SQ_Detail_box[key], "ALIGNMENT0", "ACENTER")
-	iup.SetAttribute(SQ_Detail_box[key], "ALIGNMENT1", "ALEFT")
-	iup.SetAttribute(SQ_Detail_box[key], "ALIGNMENT2", "ALEFT")
-	iup.SetAttribute(SQ_Detail_box[key],"WIDTH0", "30")
-	iup.SetAttribute(SQ_Detail_box[key],"WIDTH1", "150")
-	iup.SetAttribute(SQ_Detail_box[key],"WIDTH2", "250")
-	for _, id in ipairs (info.quests) do	-- get the quests of the zone
-	--	print (dump(id))
-		SQ_Detail_box[key].numlin = Line
-		SQ_Detail_box[key]:setcell(Line,0, tostring(id))
-
-		if Ach_Detail[id] == nil then
-			name = "UNKN"
-		else
-		name = Ach_Detail[id].name
+	local info, name, link
+	for key, info in pairs(SQ_Info) do	-- for each zone
+	--	print ("LAng: "..lang .. "  " ..key, dump(info))
+		SQ_Detail_box[lang][key]= iup.matrix {numcol=2, numcol_visible=2,  numlin=0}
+
+		local Line = 1
+		SQ_Detail_box[lang][key]:setcell(0,0, lingua[lang].L.Ach_ID)
+		SQ_Detail_box[lang][key]:setcell(0,1, lingua[lang].L.Name)
+		SQ_Detail_box[lang][key]:setcell(0,2, lingua[lang].L.Link)
+		iup.SetAttribute(SQ_Detail_box[lang][key], "READONLY", "YES")
+		iup.SetAttribute(SQ_Detail_box[lang][key], "ALIGNMENT0", "ACENTER")
+		iup.SetAttribute(SQ_Detail_box[lang][key], "ALIGNMENT1", "ALEFT")
+		iup.SetAttribute(SQ_Detail_box[lang][key], "ALIGNMENT2", "ALEFT")
+		iup.SetAttribute(SQ_Detail_box[lang][key],"WIDTH0", "30")
+		iup.SetAttribute(SQ_Detail_box[lang][key],"WIDTH1", "150")
+		iup.SetAttribute(SQ_Detail_box[lang][key],"WIDTH2", "250")
+		for _, id in ipairs (info.quests) do	-- get the quests of the zone
+		--	print (dump(id))
+			SQ_Detail_box[lang][key].numlin = Line
+			SQ_Detail_box[lang][key]:setcell(Line,0, tostring(id))
+
+			if Ach_Detail[id] == nil then
+				name = "UNKN"
+			else
+				name = Ach_Detail[id].name
+			end
+			link = SQ_dat[id].link1
+			SQ_Detail_box[lang][key]:setcell(Line,1, name)
+			SQ_Detail_box[lang][key]:setcell(Line,2, link)
+			--print(name, link)
+			Line= Line+1
 		end
-		link = SQ_dat[id].link1
-		SQ_Detail_box[key]:setcell(Line,1, name)
-		SQ_Detail_box[key]:setcell(Line,2, link)
-		--print(name, link)
-		Line= Line+1
 	end
 end

-
+SQ_Detail_Zbox = {}
 accounts = {}
 accounts_list = {}		-- String list for selection dialog
 naccounts = 0
@@ -215,6 +220,22 @@ btn_archive = iup.button{title="Archive", FGCOLOR = "#FF0000"}
 	pub_names = lingua[accounts[acc].lang].pub_names
 	grp_names = lingua[accounts[acc].lang].grp_names
 	Ach_Detail = lingua[accounts[acc].lang].Ach_Detail
+-- Create SkillQuest Achievements Detail Boxes=======================
+-- These are the same for all chars, we just just hightlight the contents appropriately
+	load_SQ_Detail(accounts[acc].lang)
+
+--Load all the detail boxes into a zbox
+	if SQ_Detail_Zbox[accounts[acc].lang] == nil then
+			SQ_Detail_Zbox[accounts[acc].lang] = iup.zbox{}
+			-- add in all the SQ_Detail boxes
+			for key,box in pairs(SQ_Detail_box[accounts[acc].lang]) do
+	--		print (dump(key, box))
+			iup.Append(SQ_Detail_Zbox[accounts[acc].lang], box)
+			end
+	end
+
+
+

   -- ====  Accountwide Data
   -- Setup Log data
@@ -729,6 +750,7 @@ btn_archive = iup.button{title="Archive", FGCOLOR = "#FF0000"}
 												iup.label{title=L.SkillLab,expand="HORIZONTAL"},
 												accounts[acc].name[char].SQ_box,
 									--			accounts[acc].name[char].SQ_Frame,
+									--			SQ_Detail_Zbox[accounts[acc].lang],
 												iup.fill{}
 											},
 								},	-- end of tabs for dungeons